"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var from_dir_1 = require("./from-dir");
var string_builder_1 = require("./string-builder");
var fs = require("fs");
var path = require("path");
exports.build = function (rootPath) {
    var content = new string_builder_1.StringBuilder();
    var home = path.resolve(rootPath);
    var sandboxes = [];
    from_dir_1.fromDir(home, /\.sandbox.ts$/, function (filename) {
        var sandboxPath = filename.replace(home, '.').replace(/.ts$/, '').replace(/\\/g, '/');
        var contents = fs.readFileSync(filename, 'utf8');
        var matchSandboxOf = /\s?sandboxOf\s*\(\s*([^)]+?)\s*\)/g.exec(contents);
        if (matchSandboxOf) {
            var typeName = matchSandboxOf[1].split(',')[0].trim();
            var labelText = /label\s*:\s*['"](.+)['"]/g.exec(matchSandboxOf[0]);
            var scenarioMenuItems = [];
            var scenarioRegex = /\.add\s*\(['"](.+)['"]\s*,\s*{/g;
            var scenarioMatches = void 0;
            var scenarioIndex = 1;
            while ((scenarioMatches = scenarioRegex.exec(contents)) !== null) {
                scenarioMenuItems.push({ key: scenarioIndex, description: scenarioMatches[1] });
                scenarioIndex++;
            }
            var label = labelText ? labelText[1] : '';
            sandboxes.push({
                key: sandboxPath,
                searchKey: "" + label + typeName,
                name: typeName,
                label: label,
                scenarioMenuItems: scenarioMenuItems
            });
        }
    });
    content.addLine("export function getSandboxMenuItems() {");
    content.addLine("return " + JSON.stringify(sandboxes) + ";");
    content.addLine("}");
    content.addLine("export function getSandbox(path: string) {");
    content.addLine("switch(path) {");
    sandboxes.forEach(function (_a) {
        var key = _a.key;
        content.addLine("case '" + key + "':");
        content.addLine("return import('" + key + "').then(sandbox => { return sandbox.default.serialize('" + key + "'); });");
    });
    content.addLine("}}");
    var filePath = path.resolve(home, './sandboxes.ts');
    fs.writeFile(filePath, content.dump(), function (err) {
        if (err) {
            return console.log(err);
        }
        console.log("Created file: " + filePath);
    });
};
